@@ -2,7 +2,6 @@
 from django.contrib.auth import (authenticate, login as auth_login,
                                                logout as auth_logout)
 from django.contrib.auth.decorators import login_required
-from django.contrib.auth.models import User
 from django.contrib.messages import info, error
 from django.core.urlresolvers import NoReverseMatch
 from django.shortcuts import get_object_or_404, redirect
@@ -10,6 +9,7 @@ from django.utils.datastructures import SortedDict
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.accounts import get_profile_model, get_profile_user_fieldname
+from mezzanine.utils.models import get_user_model
 from mezzanine.accounts import get_profile_form
 from mezzanine.accounts.forms import LoginForm, PasswordResetForm
 from mezzanine.conf import settings
@@ -18,6 +18,9 @@ from mezzanine.utils.urls import login_redirect
 from mezzanine.utils.views import render
 
 
+User = get_user_model()
+
+
 def login(request, template="accounts/account_login.html"):
     """
     Login form.
@@ -46,7 +49,7 @@ def signup(request, template="accounts/account_signup.html"):
     Signup form.
     """
     profile_form = get_profile_form()
-    form = profile_form(request.POST or None)
+    form = profile_form(request.POST or None, request.FILES or None)
     if request.method == "POST" and form.is_valid():
         new_user = form.save()
         if not new_user.is_active:
@@ -131,7 +134,8 @@ def profile_update(request, template="accounts/account_profile_update.html"):
     Profile update form.
     """
     profile_form = get_profile_form()
-    form = profile_form(request.POST or None, instance=request.user)
+    form = profile_form(request.POST or None, request.FILES or None,
+                        instance=request.user)
     if request.method == "POST" and form.is_valid():
         user = form.save()
         info(request, _("Profile updated"))
