@@ -1,4 +1,4 @@
-from __future__ import with_statement
+
 import os
 from shutil import rmtree
 from urlparse import urlparse
@@ -319,7 +319,7 @@ class Tests(TestCase):
         """
         blog_post = BlogPost.objects.create(title="Ratings", user=self._user,
                                             status=CONTENT_STATUS_PUBLISHED)
-        data = RatingForm(blog_post).initial
+        data = RatingForm(None, blog_post).initial
         for value in settings.RATINGS_RANGE:
             data["value"] = value
             response = self.client.post(reverse("rating"), data=data)
